minusTimespan method
Subtracts a Timespan. If span covers more than one day, the result
will wrap.
Implementation
@Deprecated('Use + and - operators instead.')
LocalTime minusTimespan(Timespan span) => this - span;
Subtracts a Timespan. If span covers more than one day, the result
will wrap.
@Deprecated('Use + and - operators instead.')
LocalTime minusTimespan(Timespan span) => this - span;