normalize method

  1. @Deprecated('This call is a no-op and can be removed. ' 'All Periods are now normalized by the constructor.')
Period normalize()

Returns an equivalent period where months is less than 12.

Leaves days untouched. This field can't be normalized, since the number of years or months a period of days represents varies.

Period(months: 25).normalize() == Period(years: 2, months: 1);
Period(months: 12, days: 5).normalize() == Period(years: 1, days: 5);
Period(days: 35).normalize() == Period(days: 35);  // unchanged

Implementation

@Deprecated('This call is a no-op and can be removed. '
    'All Periods are now normalized by the constructor.')
Period normalize() => this;