Weekday enum

The day of the week.

The ISO weekday number is iso, and the US weekday number is us. The index of each value is the same as iso, but you should prefer the latter for clarity.

Inheritance
Available extensions

Values

_ → const Weekday
monday → const Weekday
tuesday → const Weekday
wednesday → const Weekday
thursday → const Weekday
friday → const Weekday
saturday → const Weekday
sunday → const Weekday

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
iso int
The ISO weekday number.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
us int
The US weekday number.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Weekday>
A constant List of the values in this enum, in order of their declaration.