allTimeZones function Time zone lookups
Returns a table of time zones with information useful for choosing one.
Implementation
List<ZoneDescription> allTimeZones() =>
TimeZoneDatabase().descriptions.toList();
Returns a table of time zones with information useful for choosing one.
List<ZoneDescription> allTimeZones() =>
TimeZoneDatabase().descriptions.toList();