HasDateTime class abstract interface Local times
Interface for classes that provide date and time fields.
- Implemented types
- Implementers
Properties
- day → int
-
The day starting at 1.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hour → int
-
The hour from 0 to 23.
no setterinherited
- inLeapYear → bool
-
Determines if this date falls in a leap year.
no setterinherited
- minute → int
-
The minute from 0 to 59.
no setterinherited
- month → int
-
The month from 1 to 12.
no setterinherited
- nanosecond → int
-
The nanoseconds from 0 to 999,999,999.
no setterinherited
- ordinalDay → int
-
The number of days since the beginning of the year.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- second → int
-
The second from 0 to 59.
no setterinherited
- weekday → Weekday
-
The day of the week.
no setterinherited
- year → int
-
The year.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited