NamedZoneOffset class Absolute times
A ZoneOffset with an associated name.
This can be used interchangeably with a ZoneOffset and compares identically regardless of the name or isDst.
- Inheritance
-
- Object
- ZoneOffset
- NamedZoneOffset
Constructors
- NamedZoneOffset(String name, bool isDst, int hours, [int minutes = 0, int seconds = 0])
-
Construct a new ZoneOffset.
const
- NamedZoneOffset.fromDuration(String name, bool isDst, Duration amount)
- Constructs a new ZoneOffset from a Duration.
- NamedZoneOffset.fromTimespan(String name, bool isDst, Timespan timespan)
- Constructs a new NamedZoneOffset from a Timespan.
- NamedZoneOffset.fromZoneOffset(String name, bool isDst, ZoneOffset offset)
- Constructs a named zone offset from an unnamed one.
Properties
- asTimespan → Timespan
-
Converts this to a Timespan.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hours → int
-
UTC offset hours
[-23 to +23].finalinherited - isDst → bool
-
If true, this is a daylight savings offset.
final
- minutes → int
-
UTC offset minutes
[-59 to +59].finalinherited - name → String
-
The name for this zone offset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seconds → int
-
UTC offset seconds
[-59 to +59].finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Converts this to an ISO 8601 zone offset string.
inherited
Operators
-
operator ==(
Object other) → bool -
Equality operator.
inherited