RelativeTime class sealed Relative times
Either a Timespan or a Period.
This is a common type for functions that can operate on either a
Timespan or a Period. For example:
LocalDateTime foo(RelativeTime amount) => switch (amount) {
Period() => _fooPeriod(amount),
Timespan() => _fooTimespan(amount),
};
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited